@@ -1,16 +1,16 @@
+from .curio import *
 from .framing import *
 from .jsonrpc import *
-from .rpc import *
 from .socks import *
 from .session import *
 from .util import *
 
-_version = (0, 5, 6)
+_version = (0, 7, 3)
 _version_str = '.'.join(str(part) for part in _version)
 
-__all__ = (framing.__all__ +
+__all__ = (curio.__all__ +
+           framing.__all__ +
            jsonrpc.__all__ +
-           rpc.__all__ +
            socks.__all__ +
            session.__all__ +
            util.__all__)
